@@ -10,13 +10,12 @@
 #ifndef GETTEXTIMPORTPLUGIN_H
 #define GETTEXTIMPORTPLUGIN_H
 
-#include "lokalize_debug.h"
-
 #include "catalogfileplugin.h"
 
 #include <QRegularExpression>
 #include <QStringList>
-#include <QTextStream>
+
+class QTextStream;
 
 namespace GettextCatalog
 {
@@ -63,7 +62,7 @@ public:
     }
 
 private:
-    QByteArray codecForDevice(QIODevice * /*, bool* hadCodec*/);
+    QByteArray codecForDevice(QIODevice *);
     ConversionStatus readEntryRaw(QTextStream &stream);
     ConversionStatus readEntry(QTextStream &stream);
 
