@@ -10,14 +10,13 @@
 #ifndef CATALOGMODEL_H
 #define CATALOGMODEL_H
 
-#include "mergecatalog.h"
-#include "pos.h"
-
 #include <QAbstractItemModel>
 #include <QSortFilterProxyModel>
 #include <QVector>
 
+class MergeCatalog;
 class Catalog;
+struct DocPosition;
 
 /**
  * MVC wrapper for Catalog
@@ -36,13 +35,14 @@ public:
         TranslationStatus,
         SourceLength,
         TargetLength,
+        IsModified,
         IsEmpty,
         State,
-        IsModified,
         IsPlural,
         ColumnCount,
     };
-    static const int DisplayedColumnCount = static_cast<int>(CatalogModelColumns::TargetLength) + 1;
+    // Only show columns above IsModified (including IsModified)
+    static const int DisplayedColumnCount = static_cast<int>(CatalogModelColumns::IsModified) + 1;
 
     // Possible values in column "Translation Status".
     enum class TranslationStatus {
@@ -165,7 +165,7 @@ public Q_SLOTS:
 private:
     int m_filterOptions;
     bool m_individualRejectFilterEnable;
-    QVector<bool> m_individualRejectFilter; // used from kross scripts
+    QVector<bool> m_individualRejectFilter;
     MergeCatalog *m_mergeCatalog;
 };
 
