@@ -10,18 +10,20 @@
 #ifndef GLOSSARYVIEW_H
 #define GLOSSARYVIEW_H
 
+#include "pos.h"
+
 #include <QDockWidget>
 #include <QRegularExpression>
-#include <pos.h>
+#include <QVector>
+
 class Catalog;
 class FlowLayout;
+class QAction;
 class QDragEnterEvent;
 class QDropEvent;
 class QEvent;
-class QAction;
 class QFrame;
 class QScrollArea;
-#include <QVector>
 
 namespace GlossaryNS
 {
