@@ -7,9 +7,10 @@
 #include "languagetoolparser.h"
 #include "languagetoolgrammarerror.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <QJsonArray>
+#include <QJsonObject>
 
 QString LanguageToolParser::parseResult(const QJsonObject &obj, const QString &text) const
 {
