@@ -7,9 +7,10 @@
 #ifndef LANGUAGETOOLPARSER_H
 #define LANGUAGETOOLPARSER_H
 
-#include <QJsonObject>
 #include <QString>
 
+class QJsonObject;
+
 class LanguageToolParser
 {
 public:
