@@ -6,12 +6,14 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
+#include "project.h"
+#include "tm/jobs.h"
+
+#include <QMutex>
 #include <QSqlQuery>
 #include <QSqlRecord>
 #include <QTest>
-
-#include "project.h"
-#include "tm/jobs.h"
+#include <QThreadPool>
 
 class TmJobsTest : public QObject
 {
