@@ -8,17 +8,16 @@
 */
 
 #include "dbfilesmodel.h"
-
 #include "lokalize_debug.h"
-
 #include "project.h"
 
+#include <KLocalizedString>
+
 #include <QCoreApplication>
 #include <QFileSystemModel>
 #include <QStandardPaths>
 #include <QStringBuilder>
-
-#include <klocalizedstring.h>
+#include <QThreadPool>
 
 #if defined(Q_OS_WIN) && defined(QStringLiteral)
 #undef QStringLiteral
