@@ -10,13 +10,12 @@
 #ifndef QAVIEW_H
 #define QAVIEW_H
 
-#include <QDockWidget>
-#include <QDomDocument>
-#include <QTreeView>
-
 #include "rule.h"
 
+#include <QDockWidget>
+
 class QaModel;
+class QTreeView;
 
 class QaView : public QDockWidget
 {
