@@ -10,10 +10,11 @@
 #ifndef QARULE_H
 #define QARULE_H
 
-#include <QRegularExpression>
-#include <QString>
 #include <QVector>
 
+class QRegularExpression;
+class QString;
+
 struct StringRule {
     QVector<QString> sources;
     QVector<QString> targets;
